#!/bin/sh
# @(#) $Id: captive.sh 34 2010-10-14 20:55:09Z leres $ (LBL)

#
# PROVIDE: captive
# KEYWORD: nojail shutdown
# REQUIRE: LOGIN
#

#
# To configure, add variables to /etc/rc.conf:
#
#	captive_enable="YES"
#	captive_users		# optional captive accounts (default: captive)
#	captive*_dev		# dev dir in jail (default: ~user/dev)
#	captive*_bpf="wheel"	# bpf group for jail (default: NONE)
#

. /etc/rc.subr

name="captive"
rcvar=`set_rcvar`
start_cmd="${name}_start"
stop_cmd="${name}_stop"

load_rc_config $name
users="${captive_users:-${name}}"

captive_start() {
	for user in ${users}; do
		echo "Starting ${name}: ${user}."
		eval dev=\${${user}_dev:-~${user}/dev}
		eval bpf=\${${user}_bpf:-NO}
		if [ ! -d "${dev}" ]; then
			echo "Can't find ${dev}" 1>&2
			continue
		fi

		umount ${dev} 2>/dev/null

		devfs_rulesets_from_file /etc/defaults/devfs.rules

		devfs_domount ${dev} devfsrules_hide_all
		devfs -m ${dev} rule apply path null unhide
		devfs -m ${dev} rule apply path random unhide

		# Optionally enable bpf for the specified group
		if [ ${bpf} != "NO" ]; then
			devfs -m ${dev} rule apply path 'bpf*' unhide
			devfs -m ${dev} ruleset 10
			devfs -m ${dev} rule add path 'bpf*' mode 660 \
			    group ${bpf}
			devfs -m ${dev} rule applyset
			devfs -m ${dev} rule apply path 'bpf*' unhide
		fi
	done
}

captive_stop() {
	for user in ${users}; do
		echo "Stopping ${name}: ${user}."
		eval dev=\${${user}_dev:-~${user}/dev}
		umount ${dev}
	done
}

run_rc_command "$1"
